@@ -93,8 +93,9 @@ class Result:
 
         # Name of test with module and test function together and separate
         self.full_name = name
-        self.name = name.split('.')[-1]
-        self.module = '.'.join(name.split('.')[:-1])
+        without_parametrized_name = name.split("[")[0]
+        self.module = ".".join(without_parametrized_name.split(".")[:-1])
+        self.name = name[len(self.module)+1:]
 
         # Additional classes to add to the result card
         self.classes = [f'{k}-{str(v).lower()}' for k, v in [
@@ -130,6 +131,8 @@ class Result:
         if self.image_status == 'match':
             return "000000"
         elif self.image_status == 'diff':
+            if self.rms is None:  # Shape mismatch
+                return "999999"
             # RMS will be in [0, 255]
             return f"{(self.rms + 2) * 1000:06.0f}"
         else:  # Missing baseline image
